==> methylInheritance_1.0.0.tar.gz: methylInheritance/README.md <==
[![Build Status](https://travis-ci.org/adeschen/methylInheritance.svg?branch=master)](https://travis-ci.org/adeschen/methylInheritance)
[![codecov](https://codecov.io/gh/adeschen/methylInheritance/branch/master/graph/badge.svg)](https://codecov.io/gh/adeschen/methylInheritance)


## Conserved Differentially Methylated Elements from One Generation to the Next: Inheritance versus Randomness


The **methylInheritance** package implements a permutation analysis, based 
on Monte Carlo sampling, for testing the 
hypothesis that the number of conserved differentially methylated 
elements, between several generations, is 
associated to an effect inherited from a treatment and that stochastic effect 
can be dismissed. 

## Citing ##

If you use this package for a publication, we would ask you to cite the 
following:

> Astrid Deschênes, Pascal Belleau and Arnaud Droit (2016). methylInheritance: Permutation-Based Analysis associating Conserved Differentially Methylated Elements from One Generation to the Next to a Treatment Effect. R package version 0.99.0.

> Akalin A, Kormaksson M, Li S, Garrett-Bakelman FE, Figueroa ME, Melnick A and Mason CE (2012). “methylKit: a comprehensive R package for the analysis of genome-wide DNA methylation profiles.” Genome Biology, 13(10), pp. R87. 


## Authors ##

[Astrid Desch&ecirc;nes](http://ca.linkedin.com/in/astriddeschenes "Astrid Desch&ecirc;nes"), 
[Pascal Belleau](http://ca.linkedin.com/in/pascalbelleau "Pascal Belleau")
and [Arnaud Droit](http://ca.linkedin.com/in/drarnaud "Arnaud Droit").

See [Arnaud Droit Lab](http://bioinformatique.ulaval.ca "Arnaud Droit Lab") 
website.


## License ##

This package and the underlying methylInheritance code are distributed under 
the Artistic license 2.0. You are free to use and redistribute this software. 

For more information on Artistic 2.0 License see
[http://opensource.org/licenses/Artistic-2.0](http://opensource.org/licenses/Artistic-2.0)


## Bugs/Feature requests ##

If you have any bugs or feature requests, 
[let us know](https://github.com/adeschen/methylInheritance/issues). 

Thanks!

==> methylInheritance_1.2.0.tar.gz: methylInheritance/README.md <==
[![Build Status](https://travis-ci.org/adeschen/methylInheritance.svg?branch=master)](https://travis-ci.org/adeschen/methylInheritance)
[![codecov](https://codecov.io/gh/adeschen/methylInheritance/branch/master/graph/badge.svg)](https://codecov.io/gh/adeschen/methylInheritance)


## Conserved Differentially Methylated Elements from One Generation to the Next: Inheritance versus Randomness


The **methylInheritance** package implements a permutation analysis, based 
on Monte Carlo sampling, for testing the 
hypothesis that the number of conserved differentially methylated 
elements, between several generations, is 
associated to an effect inherited from a treatment and that stochastic effect 
can be dismissed. 

## Citing ##

If you use this package for a publication, we would ask you to cite the 
following:

> Astrid Deschênes, Pascal Belleau and Arnaud Droit (2016). methylInheritance: Permutation-Based Analysis associating Conserved Differentially Methylated Elements from One Generation to the Next to a Treatment Effect. R package version 0.99.0. DOI: 10.18129/B9.bioc.methylInheritance

> Akalin A, Kormaksson M, Li S, Garrett-Bakelman FE, Figueroa ME, Melnick A and Mason CE (2012). “methylKit: a comprehensive R package for the analysis of genome-wide DNA methylation profiles.” Genome Biology, 13(10), pp. R87. 


## Bioconductor Package ##

[![Bioconductor Time](http://bioconductor.org/shields/years-in-bioc/methylInheritance.svg)](http://bioconductor.org/packages/release/bioc/html/methylInheritance.html "Bioconductor status")

methylInheritance is now an official package of [Bioconductor](http://bioconductor.org/). The current release can be directly downloaded from their website:
[Current release](http://bioconductor.org/packages/methylInheritance)


## Authors ##

[Astrid Desch&ecirc;nes](http://ca.linkedin.com/in/astriddeschenes "Astrid Desch&ecirc;nes"), 
[Pascal Belleau](http://ca.linkedin.com/in/pascalbelleau "Pascal Belleau")
and [Arnaud Droit](http://ca.linkedin.com/in/drarnaud "Arnaud Droit").


## License ##

This package and the underlying methylInheritance code are distributed under 
the Artistic license 2.0. You are free to use and redistribute this software. 

For more information on Artistic 2.0 License see
[http://opensource.org/licenses/Artistic-2.0](http://opensource.org/licenses/Artistic-2.0)


## Bugs/Feature requests ##

If you have any bugs or feature requests, 
[let us know](https://github.com/adeschen/methylInheritance/issues). 

Thanks!
